@@ -1,5 +1,5 @@
 /* anonymous.h --- Prototypes for ANONYMOUS mechanism as defined in RFC 2245.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,13 +21,13 @@
  */
 
 #ifndef ANONYMOUS_H
-#define ANONYMOUS_H
+# define ANONYMOUS_H
 
-#include <gsasl.h>
+# include <gsasl.h>
 
-#define GSASL_ANONYMOUS_NAME "ANONYMOUS"
+# define GSASL_ANONYMOUS_NAME "ANONYMOUS"
 
-extern Gsasl_mechanism gsasl_anonymous_mechanism;
+extern Gsasl_mechanism _gsasl_anonymous_mechanism;
 
 extern int _gsasl_anonymous_client_step (Gsasl_session * sctx,
 					 void *mech_data,
