@@ -1,5 +1,5 @@
 /* client.c --- ANONYMOUS mechanism as defined in RFC 2245, client side.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
@@ -32,9 +32,10 @@
 
 int
 _gsasl_anonymous_client_step (Gsasl_session * sctx,
-			      void *mech_data,
-			      const char *input, size_t input_len,
-			      char **output, size_t * output_len)
+			      void *mech_data _GL_UNUSED,
+			      const char *input _GL_UNUSED,
+			      size_t input_len _GL_UNUSED,
+			      char **output, size_t *output_len)
 {
   const char *p;
 
