@@ -21,13 +21,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
 #include "anonymous.h"
 
-Gsasl_mechanism gsasl_anonymous_mechanism = {
+Gsasl_mechanism _gsasl_anonymous_mechanism = {
   GSASL_ANONYMOUS_NAME,
   {
    NULL,
