@@ -1,5 +1,5 @@
 /* cram-md5.h --- Prototypes for CRAM-MD5 mechanism as defined in RFC 2195.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,25 +21,25 @@
  */
 
 #ifndef CRAM_MD5_H
-#define CRAM_MD5_H
+# define CRAM_MD5_H
 
-#include <gsasl.h>
+# include <gsasl.h>
 
-#define GSASL_CRAM_MD5_NAME "CRAM-MD5"
+# define GSASL_CRAM_MD5_NAME "CRAM-MD5"
 
-extern Gsasl_mechanism gsasl_cram_md5_mechanism;
+extern Gsasl_mechanism _gsasl_cram_md5_mechanism;
 
 extern int _gsasl_cram_md5_client_step (Gsasl_session * sctx,
 					void *mech_data,
 					const char *input, size_t input_len,
-					char **output, size_t * output_len);
+					char **output, size_t *output_len);
 
 extern int _gsasl_cram_md5_server_start (Gsasl_session * sctx,
 					 void **mech_data);
 extern int _gsasl_cram_md5_server_step (Gsasl_session * sctx,
 					void *mech_data,
 					const char *input, size_t input_len,
-					char **output, size_t * output_len);
+					char **output, size_t *output_len);
 extern void _gsasl_cram_md5_server_finish (Gsasl_session * sctx,
 					   void *mech_data);
 
