@@ -21,13 +21,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
 #include "cram-md5.h"
 
-Gsasl_mechanism gsasl_cram_md5_mechanism = {
+Gsasl_mechanism _gsasl_cram_md5_mechanism = {
   GSASL_CRAM_MD5_NAME,
   {
    NULL,
