@@ -1,5 +1,5 @@
 /* digest-md5.h --- Prototypes for DIGEST-MD5 mechanism as defined in RFC 2831.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,20 +21,20 @@
  */
 
 #ifndef DIGEST_MD5_H
-#define DIGEST_MD5_H
+# define DIGEST_MD5_H
 
-#include <gsasl.h>
+# include <gsasl.h>
 
-#define GSASL_DIGEST_MD5_NAME "DIGEST-MD5"
+# define GSASL_DIGEST_MD5_NAME "DIGEST-MD5"
 
-extern Gsasl_mechanism gsasl_digest_md5_mechanism;
+extern Gsasl_mechanism _gsasl_digest_md5_mechanism;
 
 extern int _gsasl_digest_md5_client_start (Gsasl_session * sctx,
 					   void **mech_data);
 extern int _gsasl_digest_md5_client_step (Gsasl_session * sctx,
 					  void *mech_data,
 					  const char *input, size_t input_len,
-					  char **output, size_t * output_len);
+					  char **output, size_t *output_len);
 extern void _gsasl_digest_md5_client_finish (Gsasl_session * sctx,
 					     void *mech_data);
 extern int _gsasl_digest_md5_client_encode (Gsasl_session * sctx,
@@ -42,20 +42,20 @@ extern int _gsasl_digest_md5_client_encode (Gsasl_session * sctx,
 					    const char *input,
 					    size_t input_len,
 					    char **output,
-					    size_t * output_len);
+					    size_t *output_len);
 extern int _gsasl_digest_md5_client_decode (Gsasl_session * sctx,
 					    void *mech_data,
 					    const char *input,
 					    size_t input_len,
 					    char **output,
-					    size_t * output_len);
+					    size_t *output_len);
 
 extern int _gsasl_digest_md5_server_start (Gsasl_session * sctx,
 					   void **mech_data);
 extern int _gsasl_digest_md5_server_step (Gsasl_session * sctx,
 					  void *mech_data,
 					  const char *input, size_t input_len,
-					  char **output, size_t * output_len);
+					  char **output, size_t *output_len);
 extern void _gsasl_digest_md5_server_finish (Gsasl_session * sctx,
 					     void *mech_data);
 extern int _gsasl_digest_md5_server_encode (Gsasl_session * sctx,
@@ -63,12 +63,12 @@ extern int _gsasl_digest_md5_server_encode (Gsasl_session * sctx,
 					    const char *input,
 					    size_t input_len,
 					    char **output,
-					    size_t * output_len);
+					    size_t *output_len);
 extern int _gsasl_digest_md5_server_decode (Gsasl_session * sctx,
 					    void *mech_data,
 					    const char *input,
 					    size_t input_len,
 					    char **output,
-					    size_t * output_len);
+					    size_t *output_len);
 
 #endif /* DIGEST_MD5_H */
