@@ -21,13 +21,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
 #include "external.h"
 
-Gsasl_mechanism gsasl_external_mechanism = {
+Gsasl_mechanism _gsasl_external_mechanism = {
   GSASL_EXTERNAL_NAME,
   {
    NULL,
