@@ -21,13 +21,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
 #include "x-gssapi.h"
 
-Gsasl_mechanism gsasl_gssapi_mechanism = {
+Gsasl_mechanism _gsasl_gssapi_mechanism = {
   GSASL_GSSAPI_NAME,
   {
    NULL,
