@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get malloc, free. */
@@ -85,6 +85,8 @@ _gsasl_login_client_step (Gsasl_session * sctx _GL_UNUSED,
 	return GSASL_NO_PASSWORD;
 
       *output = strdup (p);
+      if (!*output)
+	return GSASL_MALLOC_ERROR;
       *output_len = strlen (*output);
 
       state->step++;
