@@ -1,5 +1,5 @@
 /* login.h --- Prototypes for non-standard SASL mechanism LOGIN.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,19 +21,19 @@
  */
 
 #ifndef LOGIN_H
-#define LOGIN_H
+# define LOGIN_H
 
-#include <gsasl.h>
+# include <gsasl.h>
 
-#define GSASL_LOGIN_NAME "LOGIN"
+# define GSASL_LOGIN_NAME "LOGIN"
 
-extern Gsasl_mechanism gsasl_login_mechanism;
+extern Gsasl_mechanism _gsasl_login_mechanism;
 
 extern int _gsasl_login_client_start (Gsasl_session * sctx, void **mech_data);
 extern int _gsasl_login_client_step (Gsasl_session * sctx,
 				     void *mech_data,
 				     const char *input, size_t input_len,
-				     char **output, size_t * output_len);
+				     char **output, size_t *output_len);
 extern void _gsasl_login_client_finish (Gsasl_session * sctx,
 					void *mech_data);
 
@@ -41,7 +41,7 @@ extern int _gsasl_login_server_start (Gsasl_session * sctx, void **mech_data);
 extern int _gsasl_login_server_step (Gsasl_session * sctx,
 				     void *mech_data,
 				     const char *input, size_t input_len,
-				     char **output, size_t * output_len);
+				     char **output, size_t *output_len);
 extern void _gsasl_login_server_finish (Gsasl_session * sctx,
 					void *mech_data);
 
