@@ -21,13 +21,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
 #include "login.h"
 
-Gsasl_mechanism gsasl_login_mechanism = {
+Gsasl_mechanism _gsasl_login_mechanism = {
   GSASL_LOGIN_NAME,
   {
    NULL,
