@@ -21,13 +21,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
 #include "x-ntlm.h"
 
-Gsasl_mechanism gsasl_ntlm_mechanism = {
+Gsasl_mechanism _gsasl_ntlm_mechanism = {
   GSASL_NTLM_NAME,
   {
    NULL,
