@@ -1,5 +1,5 @@
 /* x-ntlm.h --- Prototypes for non-standard SASL mechanism NTLM.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,13 +21,13 @@
  */
 
 #ifndef X_NTLM_H
-#define X_NTLM_H
+# define X_NTLM_H
 
-#include <gsasl.h>
+# include <gsasl.h>
 
-#define GSASL_NTLM_NAME "NTLM"
+# define GSASL_NTLM_NAME "NTLM"
 
-extern Gsasl_mechanism gsasl_ntlm_mechanism;
+extern Gsasl_mechanism _gsasl_ntlm_mechanism;
 
 extern int _gsasl_ntlm_client_start (Gsasl_session * sctx, void **mech_data);
 extern int _gsasl_ntlm_client_step (Gsasl_session * sctx,
