@@ -1,5 +1,5 @@
 /* mechinfo.c --- Definition of OPENID20 mechanism.
- * Copyright (C) 2011-2020 Simon Josefsson
+ * Copyright (C) 2011-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,13 +21,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
 #include "openid20.h"
 
-Gsasl_mechanism gsasl_openid20_mechanism = {
+Gsasl_mechanism _gsasl_openid20_mechanism = {
   GSASL_OPENID20_NAME,
   {
    NULL,
