@@ -21,13 +21,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
 #include "plain.h"
 
-Gsasl_mechanism gsasl_plain_mechanism = {
+Gsasl_mechanism _gsasl_plain_mechanism = {
   GSASL_PLAIN_NAME,
   {
    NULL,
