@@ -1,5 +1,5 @@
 /* plain.h --- Prototypes for SASL mechanism PLAIN as defined in RFC 2595.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,13 +21,13 @@
  */
 
 #ifndef PLAIN_H
-#define PLAIN_H
+# define PLAIN_H
 
-#include <gsasl.h>
+# include <gsasl.h>
 
-#define GSASL_PLAIN_NAME "PLAIN"
+# define GSASL_PLAIN_NAME "PLAIN"
 
-extern Gsasl_mechanism gsasl_plain_mechanism;
+extern Gsasl_mechanism _gsasl_plain_mechanism;
 
 extern int _gsasl_plain_client_step (Gsasl_session * sctx,
 				     void *mech_data,
