@@ -21,13 +21,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
 #include "saml20.h"
 
-Gsasl_mechanism gsasl_saml20_mechanism = {
+Gsasl_mechanism _gsasl_saml20_mechanism = {
   GSASL_SAML20_NAME,
   {
    NULL,
