@@ -21,13 +21,13 @@
  */
 
 #ifndef SAML20_H
-#define SAML20_H
+# define SAML20_H
 
-#include <gsasl.h>
+# include <gsasl.h>
 
-#define GSASL_SAML20_NAME "SAML20"
+# define GSASL_SAML20_NAME "SAML20"
 
-extern Gsasl_mechanism gsasl_saml20_mechanism;
+extern Gsasl_mechanism _gsasl_saml20_mechanism;
 
 extern int _gsasl_saml20_client_start (Gsasl_session * sctx,
 				       void **mech_data);
