@@ -21,42 +21,42 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
 #include "scram.h"
 
 #ifdef USE_SCRAM_SHA1
-Gsasl_mechanism gsasl_scram_sha1_mechanism = {
+Gsasl_mechanism _gsasl_scram_sha1_mechanism = {
   GSASL_SCRAM_SHA1_NAME,
   {
    NULL,
    NULL,
-#ifdef USE_CLIENT
+# ifdef USE_CLIENT
    _gsasl_scram_sha1_client_start,
    _gsasl_scram_client_step,
    _gsasl_scram_client_finish,
-#else
+# else
    NULL,
    NULL,
    NULL,
-#endif
+# endif
    NULL,
    NULL}
   ,
   {
    NULL,
    NULL,
-#ifdef USE_SERVER
+# ifdef USE_SERVER
    _gsasl_scram_sha1_server_start,
    _gsasl_scram_server_step,
    _gsasl_scram_server_finish,
-#else
+# else
    NULL,
    NULL,
    NULL,
-#endif
+# endif
    NULL,
    NULL}
 };
@@ -64,70 +64,70 @@ Gsasl_mechanism gsasl_scram_sha1_mechanism = {
 
 
 #ifdef USE_SCRAM_SHA1
-Gsasl_mechanism gsasl_scram_sha1_plus_mechanism = {
+Gsasl_mechanism _gsasl_scram_sha1_plus_mechanism = {
   GSASL_SCRAM_SHA1_PLUS_NAME,
   {
    NULL,
    NULL,
-#ifdef USE_CLIENT
+# ifdef USE_CLIENT
    _gsasl_scram_sha1_plus_client_start,
    _gsasl_scram_client_step,
    _gsasl_scram_client_finish,
-#else
+# else
    NULL,
    NULL,
    NULL,
-#endif
+# endif
    NULL,
    NULL}
   ,
   {
    NULL,
    NULL,
-#ifdef USE_SERVER
+# ifdef USE_SERVER
    _gsasl_scram_sha1_plus_server_start,
    _gsasl_scram_server_step,
    _gsasl_scram_server_finish,
-#else
+# else
    NULL,
    NULL,
    NULL,
-#endif
+# endif
    NULL,
    NULL}
 };
 #endif
 
 #ifdef USE_SCRAM_SHA256
-Gsasl_mechanism gsasl_scram_sha256_mechanism = {
+Gsasl_mechanism _gsasl_scram_sha256_mechanism = {
   GSASL_SCRAM_SHA256_NAME,
   {
    NULL,
    NULL,
-#ifdef USE_CLIENT
+# ifdef USE_CLIENT
    _gsasl_scram_sha256_client_start,
    _gsasl_scram_client_step,
    _gsasl_scram_client_finish,
-#else
+# else
    NULL,
    NULL,
    NULL,
-#endif
+# endif
    NULL,
    NULL}
   ,
   {
    NULL,
    NULL,
-#ifdef USE_SERVER
+# ifdef USE_SERVER
    _gsasl_scram_sha256_server_start,
    _gsasl_scram_server_step,
    _gsasl_scram_server_finish,
-#else
+# else
    NULL,
    NULL,
    NULL,
-#endif
+# endif
    NULL,
    NULL}
 };
@@ -135,35 +135,35 @@ Gsasl_mechanism gsasl_scram_sha256_mechanism = {
 
 
 #ifdef USE_SCRAM_SHA256
-Gsasl_mechanism gsasl_scram_sha256_plus_mechanism = {
+Gsasl_mechanism _gsasl_scram_sha256_plus_mechanism = {
   GSASL_SCRAM_SHA256_PLUS_NAME,
   {
    NULL,
    NULL,
-#ifdef USE_CLIENT
+# ifdef USE_CLIENT
    _gsasl_scram_sha256_plus_client_start,
    _gsasl_scram_client_step,
    _gsasl_scram_client_finish,
-#else
+# else
    NULL,
    NULL,
    NULL,
-#endif
+# endif
    NULL,
    NULL}
   ,
   {
    NULL,
    NULL,
-#ifdef USE_SERVER
+# ifdef USE_SERVER
    _gsasl_scram_sha256_plus_server_start,
    _gsasl_scram_server_step,
    _gsasl_scram_server_finish,
-#else
+# else
    NULL,
    NULL,
    NULL,
-#endif
+# endif
    NULL,
    NULL}
 };
