@@ -21,17 +21,17 @@
  */
 
 #ifndef SCRAM_H
-#define SCRAM_H
+# define SCRAM_H
 
-#include <gsasl.h>
+# include <gsasl.h>
 
-#ifdef USE_SCRAM_SHA1
+# ifdef USE_SCRAM_SHA1
 
-#define GSASL_SCRAM_SHA1_NAME "SCRAM-SHA-1"
-#define GSASL_SCRAM_SHA1_PLUS_NAME "SCRAM-SHA-1-PLUS"
+#  define GSASL_SCRAM_SHA1_NAME "SCRAM-SHA-1"
+#  define GSASL_SCRAM_SHA1_PLUS_NAME "SCRAM-SHA-1-PLUS"
 
-extern Gsasl_mechanism gsasl_scram_sha1_mechanism;
-extern Gsasl_mechanism gsasl_scram_sha1_plus_mechanism;
+extern Gsasl_mechanism _gsasl_scram_sha1_mechanism;
+extern Gsasl_mechanism _gsasl_scram_sha1_plus_mechanism;
 
 int _gsasl_scram_sha1_client_start (Gsasl_session * sctx, void **mech_data);
 
@@ -60,15 +60,15 @@ int _gsasl_scram_server_step (Gsasl_session * sctx,
 
 void _gsasl_scram_server_finish (Gsasl_session * sctx, void *mech_data);
 
-#endif
+# endif
 
-#ifdef USE_SCRAM_SHA256
+# ifdef USE_SCRAM_SHA256
 
-#define GSASL_SCRAM_SHA256_NAME "SCRAM-SHA-256"
-#define GSASL_SCRAM_SHA256_PLUS_NAME "SCRAM-SHA-256-PLUS"
+#  define GSASL_SCRAM_SHA256_NAME "SCRAM-SHA-256"
+#  define GSASL_SCRAM_SHA256_PLUS_NAME "SCRAM-SHA-256-PLUS"
 
-extern Gsasl_mechanism gsasl_scram_sha256_mechanism;
-extern Gsasl_mechanism gsasl_scram_sha256_plus_mechanism;
+extern Gsasl_mechanism _gsasl_scram_sha256_mechanism;
+extern Gsasl_mechanism _gsasl_scram_sha256_plus_mechanism;
 
 int _gsasl_scram_sha256_client_start (Gsasl_session * sctx, void **mech_data);
 
@@ -99,6 +99,6 @@ int _gsasl_scram_server_step (Gsasl_session * sctx,
 
 void _gsasl_scram_server_finish (Gsasl_session * sctx, void *mech_data);
 
-#endif
+# endif
 
 #endif /* SCRAM_H */
