@@ -27,12 +27,12 @@
 
 /* Hex encode HASHBUF which is HASH digest output and set salted
    password property to the hex encoded value. */
-void
+int
 set_saltedpassword (Gsasl_session * sctx,
 		    Gsasl_hash hash, const char *hashbuf)
 {
   char hexstr[GSASL_HASH_MAX_SIZE * 2 + 1];
 
   _gsasl_hex_encode (hashbuf, gsasl_hash_length (hash), hexstr);
-  gsasl_property_set (sctx, GSASL_SCRAM_SALTED_PASSWORD, hexstr);
+  return gsasl_property_set (sctx, GSASL_SCRAM_SALTED_PASSWORD, hexstr);
 }
