@@ -21,13 +21,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
 #include "securid.h"
 
-Gsasl_mechanism gsasl_securid_mechanism = {
+Gsasl_mechanism _gsasl_securid_mechanism = {
   GSASL_SECURID_NAME,
   {
    NULL,
