@@ -1,5 +1,5 @@
 /* error.c --- Error handling functionality.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -30,12 +30,6 @@
 
 #define ERR(name, desc) { name, #name, desc }
 
-#ifdef GSASL_NO_OBSOLETE
-#define OBS(i, name, desc) { i, NULL, NULL }
-#else
-#define OBS(i, name, desc) { name, #name, desc }
-#endif
-
 /* *INDENT-OFF* */
 static struct
 {
@@ -48,76 +42,39 @@ static struct
   ERR (GSASL_UNKNOWN_MECHANISM, N_("Unknown SASL mechanism")),
   ERR (GSASL_MECHANISM_CALLED_TOO_MANY_TIMES,
        N_("SASL mechanism called too many times")),
-  OBS (4, GSASL_TOO_SMALL_BUFFER,
-       N_("SASL function needs larger buffer (internal error)")),
-  OBS (5, GSASL_FOPEN_ERROR, N_("Could not open file in SASL library")),
-  OBS (6, GSASL_FCLOSE_ERROR, N_("Could not close file in SASL library")),
+  { 4, NULL, NULL },
+  { 5, NULL, NULL },
+  { 6, NULL, NULL },
   ERR (GSASL_MALLOC_ERROR, N_("Memory allocation error in SASL library")),
   ERR (GSASL_BASE64_ERROR, N_("Base 64 coding error in SASL library")),
   ERR (GSASL_CRYPTO_ERROR, N_("Low-level crypto error in SASL library")),
   { 10, NULL, NULL },
-  OBS (11, GSASL_NEED_CLIENT_ANONYMOUS_CALLBACK,
-       N_("SASL mechanism needs gsasl_client_callback_anonymous() callback"
-	  " (application error)")),
-  OBS (12, GSASL_NEED_CLIENT_PASSWORD_CALLBACK,
-       N_("SASL mechanism needs gsasl_client_callback_password() callback"
-	  " (application error)")),
-  OBS (13, GSASL_NEED_CLIENT_PASSCODE_CALLBACK,
-       N_("SASL mechanism needs gsasl_client_callback_passcode() callback"
-	  " (application error)")),
-  OBS (14, GSASL_NEED_CLIENT_PIN_CALLBACK,
-       N_("SASL mechanism needs gsasl_client_callback_pin() callback"
-	  " (application error)")),
-  OBS (15, GSASL_NEED_CLIENT_AUTHORIZATION_ID_CALLBACK,
-       N_("SASL mechanism needs gsasl_client_callback_authorization_id() "
-	  "callback (application error)")),
-  OBS (16, GSASL_NEED_CLIENT_AUTHENTICATION_ID_CALLBACK,
-       N_("SASL mechanism needs gsasl_client_callback_authentication_id() "
-	  "callback (application error)")),
-  OBS (17, GSASL_NEED_CLIENT_SERVICE_CALLBACK,
-       N_("SASL mechanism needs gsasl_client_callback_service() callback "
-	  "(application error)")),
-  OBS (18, GSASL_NEED_SERVER_VALIDATE_CALLBACK,
-       N_("SASL mechanism needs gsasl_server_callback_validate() callback "
-	  "(application error)")),
-  OBS (19, GSASL_NEED_SERVER_CRAM_MD5_CALLBACK,
-       N_("SASL mechanism needs gsasl_server_callback_cram_md5() callback "
-	  "(application error)")),
-  OBS (20, GSASL_NEED_SERVER_DIGEST_MD5_CALLBACK,
-       N_("SASL mechanism needs gsasl_server_callback_digest_md5() callback "
-	  "(application error)")),
-  OBS (21, GSASL_NEED_SERVER_EXTERNAL_CALLBACK,
-       N_("SASL mechanism needs gsasl_server_callback_external() callback "
-	  "(application error)")),
-  OBS (22, GSASL_NEED_SERVER_ANONYMOUS_CALLBACK,
-       N_("SASL mechanism needs gsasl_server_callback_anonymous() callback "
-	  "(application error)")),
-  OBS (23, GSASL_NEED_SERVER_REALM_CALLBACK,
-       N_("SASL mechanism needs gsasl_server_callback_realm() callback "
-	  "(application error)")),
-  OBS (24, GSASL_NEED_SERVER_SECURID_CALLBACK,
-       N_("SASL mechanism needs gsasl_server_callback_securid() callback "
-	  "(application error)")),
-  OBS (25, GSASL_NEED_SERVER_SERVICE_CALLBACK,
-       N_("SASL mechanism needs gsasl_server_callback_service() callback "
-	  "(application error)")),
-  OBS (26, GSASL_NEED_SERVER_GSSAPI_CALLBACK,
-       N_("SASL mechanism needs gsasl_server_callback_gssapi() callback "
-	  "(application error)")),
-  OBS (27, GSASL_NEED_SERVER_RETRIEVE_CALLBACK,
-       N_("SASL mechanism needs gsasl_server_callback_retrieve() callback "
-	  "(application error)")),
-  OBS (28, GSASL_UNICODE_NORMALIZATION_ERROR,
-       N_("Failed to perform Unicode Normalization on string.")),
+  { 11, NULL, NULL },
+  { 12, NULL, NULL },
+  { 13, NULL, NULL },
+  { 14, NULL, NULL },
+  { 15, NULL, NULL },
+  { 16, NULL, NULL },
+  { 17, NULL, NULL },
+  { 18, NULL, NULL },
+  { 19, NULL, NULL },
+  { 20, NULL, NULL },
+  { 21, NULL, NULL },
+  { 22, NULL, NULL },
+  { 23, NULL, NULL },
+  { 24, NULL, NULL },
+  { 25, NULL, NULL },
+  { 26, NULL, NULL },
+  { 27, NULL, NULL },
+  { 28, NULL, NULL },
   ERR (GSASL_SASLPREP_ERROR,
        N_("Could not prepare internationalized (non-ASCII) string.")),
   ERR (GSASL_MECHANISM_PARSE_ERROR,
        N_("SASL mechanism could not parse input")),
   ERR (GSASL_AUTHENTICATION_ERROR, N_("Error authenticating user")),
-  OBS (32, GSASL_CANNOT_GET_CTX,
-       N_("Cannot get internal library handle (library error)")),
+  { 32, NULL, NULL },
   ERR (GSASL_INTEGRITY_ERROR, N_("Integrity error in application payload")),
-  OBS (34, GSASL_NO_MORE_REALMS, N_("No more realms available (non-fatal)")),
+  { 34, NULL, NULL },
   ERR (GSASL_NO_CLIENT_CODE,
        N_("Client-side functionality not available in library "
 	  "(application error)")),
@@ -157,16 +114,13 @@ static struct
   ERR (GSASL_GSSAPI_UNSUPPORTED_PROTECTION_ERROR,
        N_("Other entity requested integrity or confidentiality protection "
 	  "in GSSAPI mechanism but this is currently not implemented.")),
-  ERR (GSASL_KERBEROS_V5_INIT_ERROR,
-       N_("Kerberos V5 initialization failure.")),
-  ERR (GSASL_KERBEROS_V5_INTERNAL_ERROR,
-       N_("Kerberos V5 internal error.")),
+  { 46, NULL, NULL },
+  { 47, NULL, NULL },
   ERR (GSASL_SECURID_SERVER_NEED_ADDITIONAL_PASSCODE,
        N_("SecurID needs additional passcode.")),
   ERR (GSASL_SECURID_SERVER_NEED_NEW_PIN,
        N_("SecurID needs new pin.")),
-  OBS (50, GSASL_INVALID_HANDLE,
-       N_("The provided library handle was invalid (application error)")),
+  { 50, NULL, NULL },
   ERR (GSASL_NO_CALLBACK,
        N_("No callback specified by caller (application error).")),
   ERR (GSASL_NO_ANONYMOUS_TOKEN,
