@@ -41,108 +41,99 @@
 #include "login/login.h"
 #include "ntlm/x-ntlm.h"
 
-/**
- * GSASL_VALID_MECHANISM_CHARACTERS:
- *
- * A zero-terminated character array, or string, with all ASCII
- * characters that may be used within a SASL mechanism name.
- **/
-const char *GSASL_VALID_MECHANISM_CHARACTERS =
-  "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-_";
-
 static int
 register_builtin_mechs (Gsasl * ctx)
 {
   int rc = GSASL_OK;
 
 #ifdef USE_ANONYMOUS
-  rc = gsasl_register (ctx, &gsasl_anonymous_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_anonymous_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_ANONYMOUS */
 
 #ifdef USE_EXTERNAL
-  rc = gsasl_register (ctx, &gsasl_external_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_external_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_EXTERNAL */
 
 #ifdef USE_LOGIN
-  rc = gsasl_register (ctx, &gsasl_login_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_login_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_LOGIN */
 
 #ifdef USE_PLAIN
-  rc = gsasl_register (ctx, &gsasl_plain_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_plain_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_PLAIN */
 
 #ifdef USE_SECURID
-  rc = gsasl_register (ctx, &gsasl_securid_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_securid_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_SECURID */
 
 #ifdef USE_NTLM
-  rc = gsasl_register (ctx, &gsasl_ntlm_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_ntlm_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_NTLM */
 
 #ifdef USE_DIGEST_MD5
-  rc = gsasl_register (ctx, &gsasl_digest_md5_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_digest_md5_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_DIGEST_MD5 */
 
 #ifdef USE_CRAM_MD5
-  rc = gsasl_register (ctx, &gsasl_cram_md5_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_cram_md5_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_CRAM_MD5 */
 
 #ifdef USE_SCRAM_SHA1
-  rc = gsasl_register (ctx, &gsasl_scram_sha1_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_scram_sha1_mechanism);
   if (rc != GSASL_OK)
     return rc;
 
-  rc = gsasl_register (ctx, &gsasl_scram_sha1_plus_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_scram_sha1_plus_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_SCRAM_SHA1 */
 
 #ifdef USE_SCRAM_SHA256
-  rc = gsasl_register (ctx, &gsasl_scram_sha256_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_scram_sha256_mechanism);
   if (rc != GSASL_OK)
     return rc;
 
-  rc = gsasl_register (ctx, &gsasl_scram_sha256_plus_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_scram_sha256_plus_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_SCRAM_SHA256 */
 
 #ifdef USE_SAML20
-  rc = gsasl_register (ctx, &gsasl_saml20_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_saml20_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_SAML20 */
 
 #ifdef USE_OPENID20
-  rc = gsasl_register (ctx, &gsasl_openid20_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_openid20_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_OPENID20 */
 
 #ifdef USE_GSSAPI
-  rc = gsasl_register (ctx, &gsasl_gssapi_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_gssapi_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_GSSAPI */
 
 #ifdef USE_GS2
-  rc = gsasl_register (ctx, &gsasl_gs2_krb5_mechanism);
+  rc = gsasl_register (ctx, &_gsasl_gs2_krb5_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_GSSAPI */
