@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 /* Get specification. */
@@ -225,17 +225,16 @@ _gsasl_gs2_generate_header (bool nonstd, char cbflag,
 void
 _gsasl_hex_encode (const char *in, size_t inlen, char *out)
 {
-  size_t i;
-  const char *p = in;
+  static const char trans[] = "0123456789abcdef";
 
-  for (i = 0; i < 2 * inlen;)
+  while (inlen--)
     {
-      unsigned char c = *p++;
-      out[i++] = "0123456789abcdef"[c >> 4];
-      out[i++] = "0123456789abcdef"[c & 0x0f];
+      unsigned char c = *in++;
+      *out++ = trans[(c >> 4) & 0xf];
+      *out++ = trans[c & 0xf];
     }
 
-  out[i] = '\0';
+  *out = '\0';
 }
 
 static char
